{ MIRROR.PDE }

{ ******************************************************************
  This is the 3D cooling model of a circular plate:
    Diam	: Diameter
    Thick	: Thickness

  The cooling assumes convection on front, back and edge sides
  of the plate, as well as radiative cooling on the front surface.

  Pyrex=Schott Borofloat 33
  Plate=Soda-Lime-Silica (Pilkington)

  The material properties used in the formulae below are around T=273K:

    K	: heat conductivity coefficient [W/m.K] at 273K
	  Plate		= 0.937,
	  Pyrex		= 1.04 (+0.0018*(T-273))

    rho	: specific mass [kg/m^3]
	  Plate		= 2530,
	  Pyrex		= 2230

    Cp	: specific heat [J/kg.K] at 273K
	  Plate		= 880, (at 293K)
	  Pyrex		= 620 (+4*(T-273))

   CoE	: linear expansion coefficient [um/m.K]
	  Plate 		= 8.3
	  Pyrex 		= 3.25

    eps	: emissivity (grey body)
	  Plate 		= 0.84 (at 293K)
	  Glass 	= 0.95,
	  Polished Al 	= 0.04-0.06,
	  Al+SiO coat	= 0.04,
	  Pure CVD Al 	= 0.02
	  Night sky 	= 0.75

  Equations used:
  ==============
  For heatflow inside glass:
    div(K*grad(Tx)) - rho * Cp * dt(Tx) = 0

  Convective heat loss at surface, Watt per m^2:
    E = -H * (Tx - Te)

  Radiative heatloss at front surface, Watt per m^2:
    E = -SB * (epsx * Tx^4 - epsc * Tc^4)


  Assumptions:
  ============
  Environment temperature Te is constant.
  Convection loss with forced air: H=50 W/K.m^2
  Convectionloss free flow: H=10 W/K.m^2
  Convectionloss is fixed over entire surface.
  Night sky equivalent temp is approximately -70C: Tc=200K

  Notes:
  =====
  The emission assumes that all surroundings are at 200K, which is
  obviously not the case. Especially when the mirror is in a closed
  OTA, the average temperature for radiative loss is much higher.
  An estimate could be made by averaging T over the space angle,
  i.e. the half hemisphere visible from a certain point, possibly taking
  into account an angle dependency.

  Convective heatloss is assumed to be position independent.
  When using a blower a gradient must be assumed. For example
  a raised cosine profile for 1 central blower.

  ****************************************************************** }

Title
  "Mirror Cooling"

Select
  regrid	= off

Coordinates
  cartesian3

Variables
  Tx                			{ Temperature, dep of place and time }

Definitions
{ User definable parameters }
  Diam	= 250e-3		{ Mirror diameter [m] }
  Thick	= 19e-3  		{ Mirror thickness [m] }
  Tend	= 7200			{ Simulation interval [sec] }
  K	= 0.937		{ Mirror heat conductivity [W/K.m]}
  rho	= 2530			{ Mirror specific weight [kg/m^3] }
  Cp	= 880			{ Mirror specific heat [J/kg.K] }
  Hb	= 10			{ Convective heat loss back [W/K.m^2] }
  Hf	= 10			{ Convective heat loss front [W/K.m^2] }
  Hs	= 10			{ Convective heat loss side [W/K.m^2] }
  Te	= 283                          	{ Environment air temperature [K] }
  Ts	= 293			{ Start temperature mirror [K] }
  Tc	= 200			{ Equivalent temp night sky [K] }
  Tg	= 283			{ Ground temperature, usually =Te }

{ Derived and fixed parameters }
  L	= Thick/2	  	{ Half mirror thickness [m] }
  R	= Diam/2		{ Mirror radius [m] }
  Area   = PI*R^2		{ Mirror area [m^2]}
  SB      = 5.67e-8		{ Stefan-Boltzmann constant }
  epsf	= 0.04			{ Front Emissivity (Al+SiO) }
  epsb	= 0.85			{ Back Emissivity (bare glass) }
  epsg	= 0.6			{ Emissivity ground }
  epsc	= 0.75			{ Emissivity night sky }

Initial values
  Tx	= Ts			{ Initial temperature throughout mirror }

Equations
  div(K*grad(Tx)) - rho * Cp * dt(Tx) = 0  	{ Heatflow equation }

Extrusion z = -L, L

Boundaries
  Surface 1 natural(Tx) = -Hf  * (Tx - Te) - SB*(epsf * Tx^4 - epsc * Tc^4)
  Surface 2 natural(Tx) = -Hb * (Tx - Te) - SB*(epsb * Tx^4 -  epsg * Tg^4)

  Region 1                           			{ Disk edge surface }
    layer 1
    start(R , 0)					{ Start mirror circumference on x-axis}
        natural(Tx) = -Hs * (Tx - Te)		{ Edge convective heatflow }
        arc (center = 0,0) angle=360         	{ Define mirror circumference }

Time
  from 0  by 1 to Tend

Monitors
  for t=0 by 200 to Tend surface (Tx) on z=L  as "Tx(x,y,+L)" export
  for t=0 by 200 to Tend surface (Tx) on z=-L as "Tx(x,y,-L)" export
  for t=0 by 200 to Tend surface (Tx) on x=0   as "Tx(0,y,z)" export

Histories
  history (Tx) at (0, 0, -L) at (0, 0, 0) at  (0, 0, L)

End


